@@ -1,8 +1,6 @@
 from importlib import import_module
-from rekuest.structures.default import get_default_structure_registry
-from rekuest.definition.registry import get_default_definition_registry
 import inspect
-module_path = f"hu"
+module_path = "hu"
 
 z = locals()
 y = locals()
